*************************************************************************
* Copyright 2019, DIODES INCORPORATED                                   *
* All Rights Reserved                                                   *
* CONFIDENTIAL INFORMATION -                                            *
* Diodes Incorporated PROPRIETARY                                       *
*************************************************************************

* PI3HDX1204B1 REDRIVER Simulation
* RX -- differential signal input;
* TX -- differential output signal after redriver
* for all control settings, please refer to the datasheet; 

* Redriver diff. inputs at VIP & VIN
* Redriver diff. outputs at VOP & VON

*************************************************************************
* Simulation options                                                    *
*************************************************************************
.option runlvl=0 method=gear post probe


*********************************************************
$ Temperature 						*
*********************************************************
.temp 60


*********************************************************
$ TL Model						*
*********************************************************
.MODEL model1_tl8 W MODELTYPE=RLGC, N=1
+ Lo = 2.55e-07
+ Co = 1.02e-10
+ Ro = 0.585
+ Rs = 2.5e-4
+ Gd = 2.85e-11


*************************************************************************
* Diffential Signal Input, PRBS pattern					*
*************************************************************************
.inc './prbs/prbs7.inc'


rfil	in inx	10
cfil	inx 0	1.6p

ginp	0 tpp	inx 0	'0.5/50' 
ginn	0 tpn	inx 0	'-0.5/50'

rsrcp	tpp 0		50
rsrcn	tpn 0		50


*************************************************************************
* Input channel T-line; length = 3 inches                              *
*************************************************************************
wlp N=1 tpp 0 tppa 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'
wln N=1 tpn 0 tpna 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'


*************************************************************************
* External Input AC coupling                                            *
*************************************************************************
crxp    tppa inpx	100n
crxn    tpna innx	100n


*************************************************************************
* Redriver PI3HDX1204B1							*
* hdx1204b1.inc calls subckt Redriver					*
*************************************************************************
.inc './hdx1204b1.inc'
xpi3hdx1204b1 inpx innx outpx outnx hdx1204b1


*************************************************************************
* Output AC coupling							*
*************************************************************************
ctxp2	outpx tppb	100n
ctxn2	outnx tpnb	100n

*************************************************************************
* Output channel T-line; length = 3 inches                              *
*************************************************************************
wlpb N=1 tppb 0 outpp 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'
wlnb N=1 tpnb 0 outnn 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'


*************************************************************************
* Load at Receiver							*
*************************************************************************
rpp	outpp 0		50
rnn	outnn 0 	50

*************************************************************************
* Simulation Commands and Probe						*
*************************************************************************
.op
.param datarate=6g per2='1/datarate'  dtr='20p' dtf='20p' tdelay=0n amp=600m

.tran 100p 5n 'per2/100' '5n+128*per2' 	 start=5n

.probe tran ax=par('time-int(time/per2)*per2')
.probe v(in) v(inx)
.probe v(tpp) v(tpn)		trace_in=v(tpp tpn)      * middle channel trace input
.probe v(inpx) v(innx)		redrv_in=v(inpx innx)    * middle channel redriver input
.probe v(outpx) v(outnx)	redrv_out=v(outpx outnx) * middle channel redriver out
.probe v(outpp) v(outnn)	trace_out=v(outpp outnn) * middle channel trace out
.end
